@@ -1,4 +1,3 @@
-# coding: utf-8
 require "minitest/autorun"
 require "hoe"
 require "tempfile"
@@ -192,11 +191,8 @@ class TestHoe < Minitest::Test
             "* http://docs.seattlerb.org/hoe/Hoe.pdf",
             "* http://github.com/jbarnette/hoe-plugin-examples"].join "\n"
 
-    exp = { "home" => "https://github.com/seattlerb/hoe" }
-    err = /DEPRECATED: Please switch readme to hash format/
-
-    assert_output "", err do
-      assert_equal exp, hoe.parse_urls(ary)
+    assert_raises RuntimeError do
+      hoe.parse_urls ary
     end
   end
 
@@ -265,7 +261,7 @@ class TestHoe < Minitest::Test
     h = nil
     nokogiri_readme = <<~EOM
       ## Links
-      
+
       * https://nokogiri.org
       * [Installation Help](https://nokogiri.org/tutorials/installing_nokogiri.html)
       * [Tutorials](https://nokogiri.org/tutorials/toc.html)
@@ -465,14 +461,14 @@ class TestHoe < Minitest::Test
 
   def test_nosudo
     hoe = self.hoe do
-      def system cmd
+      def sh cmd
         cmd
       end
     end
 
-    assert_match(/^(sudo )?(j|maglev-)?gem.*/, hoe.install_gem("foo"))
+    assert_match(/^(sudo )?gem.*/, hoe.install_gem("foo"))
     ENV["NOSUDO"] = "1"
-    assert_match(/^(j|maglev-)?gem.*/, hoe.install_gem("foo"))
+    assert_match(/^gem.*/, hoe.install_gem("foo"))
   ensure
     ENV.delete "NOSUDO"
   end
